==> igniteui-angular-charts-16.0.0.tgz: package/esm5/lib/igx-fragment-base-component.js <==
import { __extends } from "tslib";
import { Component } from '@angular/core';
import { IgxHorizontalAnchoredCategorySeriesComponent } from "./igx-horizontal-anchored-category-series-component";
import { toPoint, fromPoint } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents one part of a stacked series.
*/
var IgxFragmentBaseComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgxFragmentBaseComponent, _super);
    function IgxFragmentBaseComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgxFragmentBaseComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxFragmentBaseComponent.prototype, "isFragment", {
        /**
         * Gets whether the current series is a stack fragment.
        */
        get: function () {
            return this.i.dv;
        },
        enumerable: false,
        configurable: true
    });
    IgxFragmentBaseComponent.prototype.getSeriesValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.pq(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgxFragmentBaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.14", ngImport: i0, type: IgxFragmentBaseComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxFragmentBaseComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.14", type: IgxFragmentBaseComponent, selector: "ng-component", usesInheritance: true, ngImport: i0, template: "", isInline: true });
    return IgxFragmentBaseComponent;
}(IgxHorizontalAnchoredCategorySeriesComponent));
export { IgxFragmentBaseComponent };
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.14", ngImport: i0, type: IgxFragmentBaseComponent, decorators: [{
            type: Component,
            args: [{
                    template: "",
                }]
        }], ctorParameters: function () { return []; } });

==> igniteui-angular-charts-17.2.1.tgz: package/esm5/lib/igx-fragment-base-component.js <==
import { __extends } from "tslib";
import { Component } from '@angular/core';
import { IgxHorizontalAnchoredCategorySeriesComponent } from "./igx-horizontal-anchored-category-series-component";
import { toPoint, fromPoint } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents one part of a stacked series.
*/
var IgxFragmentBaseComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgxFragmentBaseComponent, _super);
    function IgxFragmentBaseComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgxFragmentBaseComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxFragmentBaseComponent.prototype, "isFragment", {
        /**
         * Gets whether the current series is a stack fragment.
        */
        get: function () {
            return this.i.eq;
        },
        enumerable: false,
        configurable: true
    });
    IgxFragmentBaseComponent.prototype.getSeriesValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.ti(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgxFragmentBaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxFragmentBaseComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxFragmentBaseComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: IgxFragmentBaseComponent, selector: "ng-component", usesInheritance: true, ngImport: i0, template: "", isInline: true });
    return IgxFragmentBaseComponent;
}(IgxHorizontalAnchoredCategorySeriesComponent));
export { IgxFragmentBaseComponent };
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxFragmentBaseComponent, decorators: [{
            type: Component,
            args: [{
                    template: "",
                }]
        }], ctorParameters: function () { return []; } });
